@@ -3,7 +3,7 @@ package Tie::STDERR;
 
 use strict;
 
-my $stderr;			### here we store the STDERR output
+my $stderr = '';		### here we store the STDERR output
 
 sub TIEHANDLE
 	{
@@ -13,7 +13,6 @@ sub TIEHANDLE
 sub PRINT
 	{
 	my $self = shift;
-	$stderr = '' unless defined $stderr;
 	$stderr .= join	'', @_;
 	}
 
@@ -23,8 +22,12 @@ my $default_mail = '| /usr/lib/sendmail -t';	### default command
 
 my ($user, $subject, $command);
 
-END {
-	if (defined $stderr)
+sub process_result
+	{
+	local *STDERR;
+	untie *STDERR;
+	local $ENV{'PATH'} = '/bin:/usr/bin:/usr/local/bin';
+	if ($stderr ne '')
 		{
 		if (defined $command)
 			{
@@ -40,9 +43,17 @@ END {
 			for (sort keys %ENV) { print OUT "$_ = $ENV{$_}\n"; }
 			}
 		close OUT;
+		$stderr = '';
 		}
 	}
 
+if (defined $ENV{'MOD_PERL'})
+	{ eval 'use Apache; my $r = Apache->request; $r->register_cleanup(\&process_result); '; }
+
+END {
+	process_result();
+	}
+
 sub import
 	{
 	### print "Import @_ called\n";
@@ -71,8 +82,8 @@ sub import
 	return unless @_;
 
 	my $arg = shift;
-	if ($arg =~ /^\s*[|>]/)
-		{ $command = $arg; }
+	if ($arg =~ /^\s*([|>].*)/s)
+		{ $command = $1; }
 	else
 		{
 		$arg =~ s/\n$//;
@@ -85,7 +96,7 @@ sub import
 
 use vars qw( $VERSION );
 
-$VERSION = '0.122';
+$VERSION = '0.20';
 
 1;
 
@@ -110,11 +121,12 @@ Tie::STDERR - Send output of your STDERR to a process or mail
 
 =head1 DESCRIPTION
 
-Send all output that would otherwise go to STDERR either by email to
+Sends all output that would otherwise go to STDERR either by email to
 root or whoever is responsible, or to a file or a process. This way
-you can change the destination of your error messages from inside of
-your script. The mail will be sent or the command run only if there
-actually is some output detected -- something like cron would do.
+you can easily change the destination of your error messages from
+B<inside> of your script. The mail will be sent or the command run
+only if there actually is some output detected -- something like
+cron would do.
 
 The behaviour of the module is directed via the arguments to use, as
 shown above. You can optionally give the name of the recipient and the
@@ -123,21 +135,31 @@ to a process. If it starts with > or >>, it will be written (appended)
 to a file. If the argument is explicit undef, if will untie previous
 tieness.
 
+The module will catch all output, including your explicit prints to
+STDERR, warnings about undefined values, dies and even dies as
+a result of compilation error. You do not need any special
+treatment/functions -- Tie::STDERR will catch all.
+
 My main goal was to provide a tool that could be used easily,
 especially (but not only) for CGI scripts. My assumption is that the
 CGI scripts should run without anything being sent to STDERR (and
 error_log, where it mixes up with other messages, even if you use
-CGI::Carp). I've found it usefull to get delivered any relevant
-information (%ENV) via email.
+CGI::Carp). We've found it usefull to get delivered the error and
+warning messages together with any relevant information (%ENV) via
+email.
+
+Under mod_perl, Tie::STDERR sends the message the same way it would
+with normal scripts.
 
 =head1 BUGS
 
 The Tie::STDERR catches the compile time errors, but it doesn't get
-the reason, only the fact that there was an error.
+the reason, only the fact that there was an error. I do not know how
+to fix this.
 
 =head1 VERSION
 
-0.122
+0.20
 
 =head1 AUTHOR
 
